#ifndef MATRIXSTRUCT_H
#define MATRIXSTRUCT_H

    #define MAX_MATRIX_ALIVE 21
    #include "typedef.h"  

    void create_matrix(int rows, int cols);
    void input(LED_WICH grp, unsigned char n);
    void input_matrix(unsigned char n);
    void free_matrix(unsigned char n);
    void get_matrix(unsigned char n);
    void logic_matrix(unsigned char n1, unsigned char n2);
    void edit_matrix(unsigned char n);
    void rand_matrix(unsigned char n);
    void copy_matrix(unsigned char n1, unsigned char n2);
    unsigned char is_Matrix_Exist(unsigned char n);


#endif
